<?php

    /**
     *	VideoJS plugin
     *
     *	@package Monstra
     *  @subpackage Plugins
     *	@author Romanenko Sergey / Awilum
     *	@copyright 2012 Romanenko Sergey / Awilum
     *	@version 1.0.1
     *
     */


    // Register plugin
    Plugin::register( __FILE__,                    
                    __('VideoJS'),
                    __('Video.js is the most widely used HTML5 Video Player available.'),  
                    '1.0.1',
                    'Awilum',                 
                    'http://monstra.org/');


    // Add action
    Action::add('theme_header', 'VideoJS::_headers');
    
    // Add shortcode
    Shortcode::add('video', 'VideoJS::_shortcode');


    /**
     * VideoJS shorcodes
     *
     *  <code>
     *      {video mp4="http://video-js.zencoder.com/oceans-clip.mp4"}
     *
     *      {video webm="http://video-js.zencoder.com/oceans-clip.webm"}
     *
     *      {video width="640" height="480" poster="image.png" mp4="http://video-js.zencoder.com/oceans-clip.mp4"}
     *  </code>
     *
     */
    class VideoJS {
         

        /**
         * VideoJS Theme Headers
         */
        public static function _headers() {
            echo ('<link href="http://vjs.zencdn.net/c/video-js.css" rel="stylesheet">
                   <script src="http://vjs.zencdn.net/c/video.js"></script>');
        }


        /**
         * VideoJS Shortcode
         */
        public static function _shortcode($attributes) {
            
            // Extract
            extract($attributes);

            // MP4 Source Supplied
            if (isset($mp4)) $mp4_source = '<source src="'.$mp4.'" type=\'video/mp4\' />'; else $mp4_source = '';

            // WebM Source Supplied
            if (isset($webm)) $webm_source = '<source src="'.$webm.'" type=\'video/webm; codecs="vp8, vorbis"\' />'; else $webm_source = '';

            // Ogg source supplied
            if (isset($ogg)) $ogg_source = '<source src="'.$ogg.'" type=\'video/ogg; codecs="theora, vorbis"\' />'; else $ogg_source = '';
      
            // Poster image supplied
            if (isset($poster)) $poster_attribute = ' poster="'.$poster.'"'; else $poster_attribute = '';
      
            // Preload the video?
            if (isset($preload)) $preload_attribute = 'preload="'+$preload+'"'; else $preload_attribute = '';

            // Autoplay the video?
            if (isset($autoplay)) $autoplay_attribute = " autoplay"; else $autoplay_attribute = "";

            // Width
            if (isset($width)) $width = $width; else $width = 640;

            // Height
            if (isset($height)) $height = $height; else $height = 264;

            // Video.js
            return ('<!-- Begin Video.js -->
                     <video class="video-js vjs-default-skin" width="'.$width.'" height="'.$height.'"'.$poster_attribute.' controls '.$preload_attribute.$autoplay_attribute.' data-setup="{}">
                        '.$mp4_source.'
                        '.$webm_source.'
                        '.$ogg_source.'
                    </video>
                    <!-- End Video.js -->');        
        }

    }